@@ -27,6 +27,9 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: transports.h,v $
+ * Revision 1.49  2006/01/20 00:32:24  csoutheren
+ * First check-in of signalling aggregation code - incomplete and disabled by default
+ *
  * Revision 1.48  2005/11/30 13:05:01  csoutheren
  * Changed tags for Doxygen
  *
@@ -552,6 +555,15 @@ class H323Transport : public PIndirectChannel
       PBYTEArray & pdu   ///<  PDU read from transport
     ) = 0;
 
+    /**Extract a protocol data unit from the transport
+       This is used by the aggregator to deblock the incoming data stream
+       into valid PDUs.
+      */
+    virtual BOOL ExtractPDU(
+      const PBYTEArray & pdu, 
+      PINDEX & len
+    ) = 0;
+
     /**Write a protocol data unit from the transport.
        This will write using the transports mechanism for PDU boundaries, for
        example UDP is a single Write() call, while for TCP there is a TPKT
@@ -806,6 +818,13 @@ class H323TransportTCP : public H323TransportIP
       PBYTEArray & pdu   ///<  PDU read from transport
     );
 
+    /**Extract a protocol data unit from the transport
+      */
+    BOOL ExtractPDU(
+      const PBYTEArray & pdu, 
+      PINDEX & len
+    );
+ 
     /**Write a protocol data unit from the transport.
        This will write using the transports mechanism for PDU boundaries, for
        example UDP is a single Write() call, while for TCP there is a TPKT
@@ -916,6 +935,13 @@ class H323TransportUDP : public H323TransportIP
       PBYTEArray & pdu   ///<  PDU read from transport
     );
 
+    /**Extract a protocol data unit from the transport
+      */
+    BOOL ExtractPDU(
+      const PBYTEArray & pdu, 
+      PINDEX & len
+    );
+ 
     /**Write a protocol data unit from the transport.
        This will write using the transports mechanism for PDU boundaries, for
        example UDP is a single Write() call, while for TCP there is a TPKT
